@@ -6,18 +6,15 @@ Puppet::Type.type(:ring_account_device).provide(
 
   optional_commands :swift_ring_builder => 'swift-ring-builder'
 
-  def self.prefetch(resource)
+  def prefetch(resource)
     @my_ring = lookup_ring
   end
 
-  def self.ring
+  def ring
     @my_ring ||= lookup_ring
   end
 
-  # TODO maybe this should be a parameter eventually so that
-  # it can be configurable
-  def self.builder_file_path
-    '/etc/swift/account.builder'
+  def self.builder_file_path(policy_index)
+      '/etc/swift/account.builder'
   end
-
 end
