@@ -11,12 +11,21 @@ Puppet::Type.newtype(:ring_account_device) do
       end
       # we have to have URI Scheme so we just add http:// and ignore it later
       uri = URI('http://' + value)
-      address = uri.host
-      port_device = uri.port
       if ['','/'].include?(uri.path)
         raise(Puppet::Error, "namevar should contain a device")
       end
-      IPAddr.new(address)
+      IPAddr.new(uri.host)
+    end
+
+    munge do |value|
+      # we have to have URI Scheme so we just add http:// and ignore it later
+      uri = URI('http://' + value)
+      ip = IPAddr.new(uri.host)
+      if ip.ipv6?
+        value.gsub(uri.host, '[' + ip.to_s + ']')
+      else
+        value
+      end
     end
   end
 
