@@ -7,7 +7,7 @@ describe 'swift::containerreconciler' do
   end
 
   let :pre_condition do
-    'class { "memcached": max_memory => 1 }'
+    'class { "memcached": }'
   end
 
   shared_examples 'swift::container::reconciler' do
@@ -35,11 +35,15 @@ describe 'swift::containerreconciler' do
         is_expected.to contain_swift_container_reconciler_config(
           'container-reconciler/request_tries').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_swift_container_reconciler_config(
-          'container-reconciler/log_name').with_value('<SERVICE DEFAULT>')
+          'container-reconciler/log_name').with_value('container-reconciler')
         is_expected.to contain_swift_container_reconciler_config(
           'container-reconciler/log_level').with_value('INFO')
         is_expected.to contain_swift_container_reconciler_config(
           'container-reconciler/log_facility').with_value('LOG_LOCAL2')
+        is_expected.to contain_swift_container_reconciler_config(
+          'container-reconciler/log_address').with_value('/dev/log')
+        is_expected.to contain_swift_container_reconciler_config(
+          'container-reconciler/log_max_line_length').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_swift_container_reconciler_config(
           'filter:cache/memcache_servers').with_value('127.0.0.1:11211')
         is_expected.to contain_swift_container_reconciler_config(
