@@ -2,6 +2,12 @@ require 'spec_helper'
 
 describe 'swift::proxy::authtoken' do
   shared_examples 'swift::proxy::authtoken' do
+    let :params do
+      {
+        :password => 'swiftpassword',
+      }
+    end
+
     describe "when using default parameters" do
       it { is_expected.to contain_swift_proxy_config('filter:authtoken/log_name').with_value('swift') }
       it { is_expected.to contain_swift_proxy_config('filter:authtoken/paste.filter_factory').with_value('keystonemiddleware.auth_token:filter_factory') }
@@ -10,7 +16,7 @@ describe 'swift::proxy::authtoken' do
       it { is_expected.to contain_swift_proxy_config('filter:authtoken/auth_type').with_value('password') }
       it { is_expected.to contain_swift_proxy_config('filter:authtoken/username').with_value('swift') }
       it { is_expected.to contain_swift_proxy_config('filter:authtoken/user_domain_id').with_value('default') }
-      it { is_expected.to contain_swift_proxy_config('filter:authtoken/password').with_value('password').with_secret(true) }
+      it { is_expected.to contain_swift_proxy_config('filter:authtoken/password').with_value('swiftpassword').with_secret(true) }
       it { is_expected.to contain_swift_proxy_config('filter:authtoken/project_name').with_value('services') }
       it { is_expected.to contain_swift_proxy_config('filter:authtoken/project_domain_id').with_value('default') }
       it { is_expected.to contain_swift_proxy_config('filter:authtoken/system_scope').with_value('<SERVICE DEFAULT>') }
@@ -25,8 +31,8 @@ describe 'swift::proxy::authtoken' do
     end
 
     describe "when overriding parameters" do
-      let :params do
-        {
+      before :each do
+        params.merge!({
           :username                     => 'swiftuser',
           :password                     => 'swiftpassword',
           :project_name                 => 'admin',
@@ -37,7 +43,7 @@ describe 'swift::proxy::authtoken' do
           :service_token_roles_required => true,
           :service_type                 => 'identity',
           :interface                    => 'internal',
-        }
+        })
       end
 
       it { is_expected.to contain_swift_proxy_config('filter:authtoken/log_name').with_value('swift') }
@@ -62,29 +68,31 @@ describe 'swift::proxy::authtoken' do
     end
 
     describe 'when overriding www_authenticate_uri' do
-      let :params do
-        { :www_authenticate_uri => 'http://public.host/keystone/main' }
+      before :each do
+        params.merge!({
+          :www_authenticate_uri => 'http://public.host/keystone/main'
+        })
       end
 
       it { is_expected.to contain_swift_proxy_config('filter:authtoken/www_authenticate_uri').with_value('http://public.host/keystone/main') }
     end
 
     describe "when auth_url is set" do
-      let :params do
-        {
+      before :each do
+        params.merge!({
           :auth_url => 'https://foo.bar:5000/'
-        }
+        })
       end
 
       it { is_expected.to contain_swift_proxy_config('filter:authtoken/auth_url').with_value('https://foo.bar:5000/') }
     end
 
     describe "when both www_authenticate_uri and auth_url are set" do
-      let :params do
-        {
+      before :each do
+        params.merge!({
           :www_authenticate_uri => 'https://foo.bar:5000/v3/',
           :auth_url             => 'https://foo.bar:5000/'
-        }
+        })
       end
 
       it { is_expected.to contain_swift_proxy_config('filter:authtoken/www_authenticate_uri').with_value('https://foo.bar:5000/v3/') }
@@ -92,10 +100,10 @@ describe 'swift::proxy::authtoken' do
     end
 
     describe 'when system_scope is set' do
-      let :params do
-        {
+      before :each do
+        params.merge!({
           :system_scope => 'all'
-        }
+        })
       end
 
       it { is_expected.to contain_swift_proxy_config('filter:authtoken/project_name').with_value('<SERVICE DEFAULT>') }
