@@ -78,20 +78,24 @@ describe 'swift::proxy::ceilometer' do
       end
 
       it { is_expected.to contain_oslo__messaging__rabbit('swift_ceilometer_config').with(
-        :rabbit_ha_queues            => '<SERVICE DEFAULT>',
-        :heartbeat_timeout_threshold => '<SERVICE DEFAULT>',
-        :heartbeat_rate              => '<SERVICE DEFAULT>',
-        :heartbeat_in_pthread        => '<SERVICE DEFAULT>',
-        :rabbit_qos_prefetch_count   => '<SERVICE DEFAULT>',
-        :amqp_durable_queues         => '<SERVICE DEFAULT>',
-        :kombu_ssl_ca_certs          => '<SERVICE DEFAULT>',
-        :kombu_ssl_certfile          => '<SERVICE DEFAULT>',
-        :kombu_ssl_keyfile           => '<SERVICE DEFAULT>',
-        :kombu_ssl_version           => '<SERVICE DEFAULT>',
-        :rabbit_use_ssl              => '<SERVICE DEFAULT>',
-        :kombu_reconnect_delay       => '<SERVICE DEFAULT>',
-        :kombu_failover_strategy     => '<SERVICE DEFAULT>',
-        :kombu_compression           => '<SERVICE DEFAULT>',
+        :rabbit_ha_queues              => '<SERVICE DEFAULT>',
+        :rabbit_quorum_queue           => '<SERVICE DEFAULT>',
+        :rabbit_transient_quorum_queue => '<SERVICE DEFAULT>',
+        :heartbeat_timeout_threshold   => '<SERVICE DEFAULT>',
+        :heartbeat_rate                => '<SERVICE DEFAULT>',
+        :rabbit_qos_prefetch_count     => '<SERVICE DEFAULT>',
+        :amqp_durable_queues           => '<SERVICE DEFAULT>',
+        :amqp_auto_delete              => '<SERVICE DEFAULT>',
+        :kombu_ssl_ca_certs            => '<SERVICE DEFAULT>',
+        :kombu_ssl_certfile            => '<SERVICE DEFAULT>',
+        :kombu_ssl_keyfile             => '<SERVICE DEFAULT>',
+        :kombu_ssl_version             => '<SERVICE DEFAULT>',
+        :rabbit_use_ssl                => '<SERVICE DEFAULT>',
+        :rabbit_quorum_delivery_limit  => '<SERVICE DEFAULT>',
+        :rabbit_transient_queues_ttl   => '<SERVICE DEFAULT>',
+        :kombu_reconnect_delay         => '<SERVICE DEFAULT>',
+        :kombu_failover_strategy       => '<SERVICE DEFAULT>',
+        :kombu_compression             => '<SERVICE DEFAULT>',
       )}
 
       context 'with overridden rabbit ssl params' do
