@@ -21,12 +21,19 @@
 require 'spec_helper'
 
 describe 'swift::proxy::container_quotas' do
-
-  let :facts do
-    {}
+  shared_examples 'swift::proxy::container_quotas' do
+    it { should contain_swift_proxy_config('filter:container_quotas/use').with_value('egg:swift#container_quotas') }
   end
 
-  it { is_expected.to contain_concat_fragment('swift_container_quotas').with_content(/\[filter:container_quotas\]/) }
-  it { is_expected.to contain_concat_fragment('swift_container_quotas').with_content(/use = egg:swift#container_quotas/) }
+  on_supported_os({
+    :supported_os => OSDefaults.get_supported_os
+  }).each do |os,facts|
+    context "on #{os}" do
+      let (:facts) do
+        facts.merge(OSDefaults.get_facts())
+      end
 
+      it_configures 'swift::proxy::container_quotas'
+    end
+  end
 end
