@@ -8,7 +8,7 @@ describe 'swift::proxy' do
 
     describe 'with proper dependencies' do
       let :pre_condition do
-        "class { memcached: max_memory => 1}
+        "class { memcached: }
          class { swift: swift_hash_path_suffix => string }
          include swift::proxy::catch_errors
          include swift::proxy::gatekeeper
@@ -57,6 +57,8 @@ describe 'swift::proxy' do
         it { should contain_service('swift-proxy-server').that_notifies('Anchor[swift::service::end]') }
         it { should contain_swift_proxy_config('DEFAULT/bind_port').with_value('8080') }
         it { should contain_swift_proxy_config('DEFAULT/bind_ip').with_value('127.0.0.1') }
+        it { should contain_swift_proxy_config('DEFAULT/cert_file').with_value('<SERVICE DEFAULT>') }
+        it { should contain_swift_proxy_config('DEFAULT/key_file').with_value('<SERVICE DEFAULT>') }
         it { should contain_swift_proxy_config('DEFAULT/workers').with_value('2') }
         it { should contain_swift_proxy_config('DEFAULT/user').with_value('swift') }
         it { should contain_swift_proxy_config('DEFAULT/log_name').with_value('proxy-server') }
@@ -88,6 +90,8 @@ describe 'swift::proxy' do
         it { should contain_swift_proxy_config('app:proxy-server/write_affinity').with_value('<SERVICE DEFAULT>') }
         it { should contain_swift_proxy_config('app:proxy-server/write_affinity_node_count').with_value('<SERVICE DEFAULT>') }
         it { should contain_swift_proxy_config('app:proxy-server/write_affinity_handoff_delete_count').with_value('<SERVICE DEFAULT>') }
+        it { should contain_swift_proxy_config('app:proxy-server/swift_owner_headers').with_value('<SERVICE DEFAULT>') }
+        it { should contain_swift_proxy_config('app:proxy-server/stale_worker_timeout').with_value('<SERVICE DEFAULT>') }
         it { should contain_swift_proxy_config('app:proxy-server/node_timeout').with_value('<SERVICE DEFAULT>') }
         it { should contain_swift_proxy_config('app:proxy-server/recoverable_node_timeout').with_value('<SERVICE DEFAULT>') }
         it { should contain_swift_proxy_config('app:proxy-server/allow_open_expired').with_value('<SERVICE DEFAULT>') }
@@ -110,7 +114,7 @@ describe 'swift::proxy' do
         describe "when using swift_proxy_config resource" do
           let :pre_condition do
             "
-              class { memcached: max_memory => 1}
+              class { memcached: }
               class { swift: swift_hash_path_suffix => string }
               swift_proxy_config { 'foo/bar': value => 'foo' }
               include swift::proxy::catch_errors
@@ -127,17 +131,18 @@ describe 'swift::proxy' do
 
         describe 'when more parameters are set' do
           let :pre_condition do
-            "class { memcached: max_memory => 1}
-             class { swift: swift_hash_path_suffix => string }
-             include swift::proxy::swauth"
+            "class { memcached: }
+             class { swift: swift_hash_path_suffix => string }"
           end
 
           let :params do
             {
               :proxy_local_net_ip                  => '10.0.0.2',
               :port                                => '80',
+              :cert_file                           => '/path/to/cert',
+              :key_file                            => '/path/to/key',
               :workers                             => 3,
-              :pipeline                            => ['swauth', 'proxy-server'],
+              :pipeline                            => ['proxy-server'],
               :allow_account_management            => false,
               :account_autocreate                  => false,
               :log_level                           => 'DEBUG',
@@ -153,6 +158,8 @@ describe 'swift::proxy' do
               :write_affinity                      => 'r1',
               :write_affinity_node_count           => '2 * replicas',
               :write_affinity_handoff_delete_count => 'auto',
+              :swift_owner_headers                 => ['x-container-read', 'x-container-write'],
+              :stale_worker_timeout                => 86400,
               :client_timeout                      => '120',
               :keepalive_timeout                   => '121',
               :node_timeout                        => '20',
@@ -166,6 +173,8 @@ describe 'swift::proxy' do
 
           it { should contain_swift_proxy_config('DEFAULT/bind_port').with_value('80') }
           it { should contain_swift_proxy_config('DEFAULT/bind_ip').with_value('10.0.0.2') }
+          it { should contain_swift_proxy_config('DEFAULT/cert_file').with_value('/path/to/cert') }
+          it { should contain_swift_proxy_config('DEFAULT/key_file').with_value('/path/to/key') }
           it { should contain_swift_proxy_config('DEFAULT/workers').with_value('3') }
           it { should contain_swift_proxy_config('DEFAULT/user').with_value('swift') }
           it { should contain_swift_proxy_config('DEFAULT/log_name').with_value('swift-proxy-server') }
@@ -175,7 +184,7 @@ describe 'swift::proxy' do
           it { should contain_swift_proxy_config('DEFAULT/log_address').with_value('/dev/log') }
           it { should contain_swift_proxy_config('DEFAULT/client_timeout').with_value('120') }
           it { should contain_swift_proxy_config('DEFAULT/keepalive_timeout').with_value('121') }
-          it { should contain_swift_proxy_config('pipeline:main/pipeline').with_value('swauth proxy-server') }
+          it { should contain_swift_proxy_config('pipeline:main/pipeline').with_value('proxy-server') }
           it { should contain_swift_proxy_config('app:proxy-server/use').with_value('egg:swift#proxy') }
           it { should contain_swift_proxy_config('app:proxy-server/set log_name').with_value('swift-proxy-server') }
           it { should contain_swift_proxy_config('app:proxy-server/set log_facility').with_value('LOG_LOCAL2') }
@@ -195,6 +204,8 @@ describe 'swift::proxy' do
           it { should contain_swift_proxy_config('app:proxy-server/write_affinity').with_value('r1') }
           it { should contain_swift_proxy_config('app:proxy-server/write_affinity_node_count').with_value('2 * replicas') }
           it { should contain_swift_proxy_config('app:proxy-server/write_affinity_handoff_delete_count').with_value('auto') }
+          it { should contain_swift_proxy_config('app:proxy-server/swift_owner_headers').with_value('x-container-read,x-container-write') }
+          it { should contain_swift_proxy_config('app:proxy-server/stale_worker_timeout').with_value(86400) }
           it { should contain_swift_proxy_config('app:proxy-server/node_timeout').with_value('20') }
           it { should contain_swift_proxy_config('app:proxy-server/recoverable_node_timeout').with_value('15') }
           it { should contain_swift_proxy_config('app:proxy-server/allow_open_expired').with_value(false) }
@@ -208,7 +219,7 @@ describe 'swift::proxy' do
             let :params do
               {
                 :proxy_local_net_ip => '10.0.0.2',
-                :pipeline           => ['swauth', 'proxy-server'],
+                :pipeline           => ['tempauth', 'proxy-server'],
                 :log_level          => 'DEBUG',
                 :log_name           => 'swift-proxy-server',
                 :log_udp_host       => '127.0.0.1',
@@ -218,9 +229,10 @@ describe 'swift::proxy' do
             end
 
             let :pre_condition do
-              "class { memcached: max_memory => 1}
+              "class { memcached: }
                class { swift: swift_hash_path_suffix => string }
-               include swift::proxy::swauth"
+               include swift::proxy::tempauth
+               "
             end
 
             it { should contain_swift_proxy_config('DEFAULT/bind_ip').with_value('10.0.0.2') }
@@ -231,7 +243,7 @@ describe 'swift::proxy' do
             it { should contain_swift_proxy_config('DEFAULT/log_address').with_value('/dev/log') }
             it { should contain_swift_proxy_config('DEFAULT/log_udp_host').with_value('127.0.0.1') }
             it { should contain_swift_proxy_config('DEFAULT/log_udp_port').with_value('514') }
-            it { should contain_swift_proxy_config('pipeline:main/pipeline').with_value('swauth proxy-server') }
+            it { should contain_swift_proxy_config('pipeline:main/pipeline').with_value('tempauth proxy-server') }
             it { should contain_swift_proxy_config('app:proxy-server/use').with_value('egg:swift#proxy') }
             it { should contain_swift_proxy_config('app:proxy-server/set log_name').with_value('swift-proxy-server') }
             it { should contain_swift_proxy_config('app:proxy-server/set log_facility').with_value('LOG_LOCAL2') }
@@ -299,7 +311,7 @@ describe 'swift::proxy' do
     end
 
     let :pre_condition do
-      "class { memcached: max_memory => 1}
+      "class { memcached: }
        class { swift: swift_hash_path_suffix => string }
        include swift::proxy::catch_errors
        include swift::proxy::gatekeeper
