@@ -62,7 +62,6 @@ describe 'swift::storage::server' do
         :owner  => 'root',
         :group  => 'swift',
         :mode   => '0640',
-        :tag    => 'swift-config-file'
       )}
 
       it {
@@ -83,6 +82,7 @@ describe 'swift::storage::server' do
         is_expected.to contain_swift_account_config('DEFAULT/log_address').with_value('/dev/log')
         is_expected.to contain_swift_account_config('DEFAULT/log_udp_host').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_swift_account_config('DEFAULT/log_udp_port').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_swift_account_config('DEFAULT/log_max_line_length').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_swift_account_config('pipeline:main/pipeline').with_value('account-server')
         is_expected.to contain_swift_account_config('app:account-server/use').with_value('egg:swift#account')
         is_expected.to contain_swift_account_config('app:account-server/set log_name').with_value('account-server')
@@ -91,6 +91,7 @@ describe 'swift::storage::server' do
         is_expected.to contain_swift_account_config('app:account-server/set log_requests').with_value(true)
         is_expected.to contain_swift_account_config('app:account-server/set log_address').with_value('/dev/log')
         is_expected.to contain_swift_account_config('app:account-server/fallocate_reserve').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_swift_account_config('app:account-server/stale_worker_timeout').with_value('<SERVICE DEFAULT>')
 
         is_expected.to contain_swift_account_config('DEFAULT/log_statsd_host').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_swift_account_config('DEFAULT/log_statsd_port').with_value('<SERVICE DEFAULT>')
@@ -246,14 +247,12 @@ describe 'swift::storage::server' do
         :owner  => 'root',
         :group  => 'swift',
         :mode   => '0640',
-        :tag    => 'swift-config-file'
       )}
       it { is_expected.to contain_file('/etc/swift/container-sync-realms.conf').with(
         :ensure => 'file',
         :owner  => 'root',
         :group  => 'swift',
         :mode   => '0640',
-        :tag    => 'swift-config-file'
       )}
 
       it {
@@ -273,6 +272,7 @@ describe 'swift::storage::server' do
         is_expected.to contain_swift_container_config('DEFAULT/log_address').with_value('/dev/log')
         is_expected.to contain_swift_container_config('DEFAULT/log_udp_host').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_swift_container_config('DEFAULT/log_udp_port').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_swift_container_config('DEFAULT/log_max_line_length').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_swift_container_config('pipeline:main/pipeline').with_value('container-server')
         is_expected.to contain_swift_container_config('app:container-server/use').with_value('egg:swift#container')
         is_expected.to contain_swift_container_config('app:container-server/set log_name').with_value('container-server')
@@ -281,6 +281,7 @@ describe 'swift::storage::server' do
         is_expected.to contain_swift_container_config('app:container-server/set log_requests').with_value(true)
         is_expected.to contain_swift_container_config('app:container-server/set log_address').with_value('/dev/log')
         is_expected.to contain_swift_container_config('app:container-server/fallocate_reserve').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_swift_container_config('app:container-server/stale_worker_timeout').with_value('<SERVICE DEFAULT>')
 
         is_expected.to contain_swift_container_config('DEFAULT/log_statsd_host').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_swift_container_config('DEFAULT/log_statsd_port').with_value('<SERVICE DEFAULT>')
@@ -448,7 +449,6 @@ describe 'swift::storage::server' do
         :owner  => 'root',
         :group  => 'swift',
         :mode   => '0640',
-        :tag    => 'swift-config-file'
       )}
 
       it {
@@ -468,6 +468,7 @@ describe 'swift::storage::server' do
         is_expected.to contain_swift_object_config('DEFAULT/log_address').with_value('/dev/log')
         is_expected.to contain_swift_object_config('DEFAULT/log_udp_host').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_swift_object_config('DEFAULT/log_udp_port').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_swift_object_config('DEFAULT/log_max_line_length').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_swift_object_config('pipeline:main/pipeline').with_value('object-server')
         is_expected.to contain_swift_object_config('app:object-server/use').with_value('egg:swift#object')
         is_expected.to contain_swift_object_config('app:object-server/set log_name').with_value('object-server')
@@ -476,6 +477,7 @@ describe 'swift::storage::server' do
         is_expected.to contain_swift_object_config('app:object-server/set log_requests').with_value(true)
         is_expected.to contain_swift_object_config('app:object-server/set log_address').with_value('/dev/log')
         is_expected.to contain_swift_object_config('app:object-server/fallocate_reserve').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_swift_object_config('app:object-server/stale_worker_timeout').with_value('<SERVICE DEFAULT>')
 
         is_expected.to contain_swift_object_config('DEFAULT/log_statsd_host').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_swift_object_config('DEFAULT/log_statsd_port').with_value('<SERVICE DEFAULT>')
